From 5937b57664585c05f4818884210e33b7632df067 Mon Sep 17 00:00:00 2001
From: Jean-Paul Saman <jpsaman@videolan.org>
Date: Tue, 23 Apr 2013 13:55:19 +0200
Subject: [PATCH 3/4] access_dvb/dtv: support for libdvbpsi >= 1.0.0

Allow compiling against libdvbpsi 1.0.0 or greater.
---
 modules/access/dtv/en50221.c |  10 ++++
 modules/access/dvb/scan.c    | 123 ++++++++++++++++++++++++++++++++++++++++---
 2 files changed, 126 insertions(+), 7 deletions(-)

diff --git a/modules/access/dtv/en50221.c b/modules/access/dtv/en50221.c
index 5bc780a..25158f7 100644
--- a/modules/access/dtv/en50221.c
+++ b/modules/access/dtv/en50221.c
@@ -58,6 +58,16 @@
 #include "../demux/dvb-text.h"
 #include "dtv/en50221.h"
 
+/*
+ * dvbpsi compatibility macros:
+ * dvbpsi version 1.0.0 and above returns a struct 'dvbpsi_t' as handle
+ */
+#define DVBPSI_VERSION_WANTED(major,minor,bugfix) (((major)<<16)+((minor)<<8)+(bugfix))
+
+#if (DVBPSI_VERSION_INT >= DVBPSI_VERSION_WANTED(1,0,0))
+# define dvbpsi_DeletePMT(table)        dvbpsi_pmt_delete((table))
+#endif
+
 typedef struct en50221_session_t
 {
     unsigned i_slot;
diff --git a/modules/access/dvb/scan.c b/modules/access/dvb/scan.c
index d4d7d1e..d641b54 100644
--- a/modules/access/dvb/scan.c
+++ b/modules/access/dvb/scan.c
@@ -56,6 +56,38 @@
 #include "scan.h"
 #include "../../demux/dvb-text.h"
 
+/*
+ * dvbpsi compatibility macros:
+ * dvbpsi version 1.0.0 and above returns a struct 'dvbpsi_t' as handle
+ */
+#define DVBPSI_VERSION_WANTED(major,minor,bugfix) (((major)<<16)+((minor)<<8)+(bugfix))
+
+#if (DVBPSI_VERSION_INT >= DVBPSI_VERSION_WANTED(1,0,0))
+# define dvbpsi_handle dvbpsi_t*
+# define dvbpsi_PushPacket(handle,data) dvbpsi_packet_push((handle),(data))
+# define dvbpsi_DeleteSDT(table)        dvbpsi_sdt_delete((table))
+# define dvbpsi_DeleteEIT(table)        dvbpsi_eit_delete((table))
+# define dvbpsi_DeleteNIT(table)        dvbpsi_nit_delete((table))
+# define dvbpsi_DeletePMT(table)        dvbpsi_pmt_delete((table))
+# define dvbpsi_DeletePAT(table)        dvbpsi_pat_delete((table))
+
+# define dvbpsi_DetachPAT(pat)          dvbpsi_pat_detach((pat))
+
+static void dvbpsi_messages(dvbpsi_t *p_dvbpsi, const dvbpsi_msg_level_t level, const char* msg)
+{
+    vlc_object_t *obj = (vlc_object_t *)p_dvbpsi->p_sys;
+
+    /* See dvbinfo.h for the definition of these log levels.*/
+    switch(level)
+    {
+        case DVBPSI_MSG_ERROR: msg_Err( obj, "%s", msg ); break;
+        case DVBPSI_MSG_WARN:  msg_Warn( obj, "%s", msg ); break;
+        case DVBPSI_MSG_DEBUG: msg_Dbg( obj, "%s", msg ); break;
+        default: msg_Info( obj, "%s", msg ); break;
+    }
+}
+#endif
+
 typedef enum
 {
     SERVICE_UNKNOWN = 0,
@@ -750,7 +782,12 @@ static void SDTCallBack( scan_session_t *p_session, dvbpsi_sdt_t *p_sdt )
 
     /* */
     msg_Dbg( p_obj, "new SDT ts_id=%d version=%d current_next=%d network_id=%d",
-             p_sdt->i_ts_id, p_sdt->i_version, p_sdt->b_current_next,
+#if (DVBPSI_VERSION_INT >= DVBPSI_VERSION_WANTED(1,0,0))
+             p_sdt->i_extension,
+#else
+             p_sdt->i_ts_id,
+#endif
+             p_sdt->i_version, p_sdt->b_current_next,
              p_sdt->i_network_id );
 
 
@@ -930,15 +967,33 @@ static void NITCallBack( scan_session_t *p_session, dvbpsi_nit_t *p_nit )
 }
 #endif
 
+#if (DVBPSI_VERSION_INT >= DVBPSI_VERSION_WANTED(1,0,0))
+static void PSINewTableCallBack( dvbpsi_t *h, uint8_t i_table_id, uint16_t i_extension, void *p_data )
+{
+    scan_session_t *p_session = (scan_session_t *)p_data;
+
+    if( i_table_id == 0x42 )
+    {
+        if( !dvbpsi_sdt_attach( h, i_table_id, i_extension, (dvbpsi_sdt_callback)SDTCallBack, p_session ) )
+            msg_Err( p_session->p_obj, "PSINewTableCallback: failed attaching SDTCallback" );
+    }
+    else if( i_table_id == 0x40 || i_table_id == 0x41 )
+    {
+        if( !dvbpsi_nit_attach( h, i_table_id, i_extension, (dvbpsi_nit_callback)NITCallBack, p_session ) )
+            msg_Err( p_session->p_obj, "PSINewTableCallback: failed attaching NITCallback" );
+    }
+}
+#else
 static void PSINewTableCallBack( scan_session_t *p_session, dvbpsi_handle h, uint8_t  i_table_id, uint16_t i_extension )
 {
     if( i_table_id == 0x42 )
         dvbpsi_AttachSDT( h, i_table_id, i_extension, (dvbpsi_sdt_callback)SDTCallBack, p_session );
-#ifdef DVBPSI_USE_NIT
+# ifdef DVBPSI_USE_NIT
     else if( i_table_id == 0x40 || i_table_id == 0x41 )
         dvbpsi_AttachNIT( h, i_table_id, i_extension, (dvbpsi_nit_callback)NITCallBack, p_session );
-#endif
+# endif
 }
+#endif
 
 scan_session_t *scan_session_New( vlc_object_t *p_obj,
                                   const scan_configuration_t *p_cfg )
@@ -1074,7 +1129,6 @@ void scan_session_Destroy( scan_t *p_scan, scan_session_t *p_session )
 #endif
     }
 
-
     /* */
     if( p_session->pat )
         dvbpsi_DetachPAT( p_session->pat );
@@ -1085,6 +1139,7 @@ void scan_session_Destroy( scan_t *p_scan, scan_session_t *p_session )
         dvbpsi_DetachDemux( p_session->sdt );
     if( p_session->p_sdt )
         dvbpsi_DeleteSDT( p_session->p_sdt );
+
 #ifdef DVBPSI_USE_NIT
     if( p_session->nit )
         dvbpsi_DetachDemux( p_session->nit );
@@ -1207,15 +1262,52 @@ bool scan_session_Push( scan_session_t *p_scan, block_t *p_block )
     if( i_pid == 0x00 )
     {
         if( !p_scan->pat )
+#if (DVBPSI_VERSION_INT >= DVBPSI_VERSION_WANTED(1,0,0))
+        {
+            p_scan->pat = dvbpsi_new( &dvbpsi_messages, DVBPSI_MSG_DEBUG );
+            if( !p_scan->pat )
+            {
+                block_Release( p_block );
+                return false;
+            }
+            p_scan->pat->p_sys = (void *) VLC_OBJECT(p_scan->p_obj);
+            if( !dvbpsi_pat_attach( p_scan->pat, (dvbpsi_pat_callback)PATCallBack, p_scan ) )
+            {
+                dvbpsi_delete( p_scan->pat );
+                p_scan->pat = NULL;
+                block_Release( p_block );
+                return false;
+            }
+        }
+#else
             p_scan->pat = dvbpsi_AttachPAT( (dvbpsi_pat_callback)PATCallBack, p_scan );
-
+#endif
         if( p_scan->pat )
             dvbpsi_PushPacket( p_scan->pat, p_block->p_buffer );
     }
     else if( i_pid == 0x11 )
     {
         if( !p_scan->sdt )
+#if (DVBPSI_VERSION_INT >= DVBPSI_VERSION_WANTED(1,0,0))
+        {
+            p_scan->sdt = dvbpsi_new( &dvbpsi_messages, DVBPSI_MSG_DEBUG );
+            if( !p_scan->sdt )
+            {
+                block_Release( p_block );
+                return false;
+            }
+            p_scan->sdt->p_sys = (void *) VLC_OBJECT(p_scan->p_obj);
+            if( !dvbpsi_AttachDemux( p_scan->sdt, (dvbpsi_demux_new_cb_t)PSINewTableCallBack, p_scan ) )
+            {
+                dvbpsi_delete( p_scan->sdt );
+                p_scan->sdt = NULL;
+                block_Release( p_block );
+                return false;
+            }
+        }
+#else
             p_scan->sdt = dvbpsi_AttachDemux( (dvbpsi_demux_new_cb_t)PSINewTableCallBack, p_scan );
+#endif
 
         if( p_scan->sdt )
             dvbpsi_PushPacket( p_scan->sdt, p_block->p_buffer );
@@ -1224,8 +1316,26 @@ bool scan_session_Push( scan_session_t *p_scan, block_t *p_block )
     {
 #ifdef DVBPSI_USE_NIT
         if( !p_scan->nit )
+# if (DVBPSI_VERSION_INT >= DVBPSI_VERSION_WANTED(1,0,0))
+        {
+            p_scan->nit = dvbpsi_new( &dvbpsi_messages, DVBPSI_MSG_DEBUG );
+            if( !p_scan->nit )
+            {
+                block_Release( p_block );
+                return false;
+            }
+            p_scan->nit->p_sys = (void *) VLC_OBJECT(p_scan->p_obj);
+            if( !dvbpsi_AttachDemux( p_scan->nit, (dvbpsi_demux_new_cb_t)PSINewTableCallBack, p_scan ) )
+            {
+                dvbpsi_delete( p_scan->nit );
+                p_scan->nit = NULL;
+                block_Release( p_block );
+                return false;
+            }
+        }
+# else
             p_scan->nit = dvbpsi_AttachDemux( (dvbpsi_demux_new_cb_t)PSINewTableCallBack, p_scan );
-
+# endif
         if( p_scan->nit )
             dvbpsi_PushPacket( p_scan->nit, p_block->p_buffer );
 #endif
@@ -1245,4 +1355,3 @@ void scan_service_SetSNR( scan_session_t *p_session, int i_snr )
 {
     p_session->i_snr = i_snr;
 }
-
-- 
1.7.11.7

